@@ -5,6 +5,7 @@ from typing import Any, Literal, Self, TypeAlias
 import stjames
 from pydantic import BaseModel, Field
 from rdkit import Chem
+from stjames.optimization.freezing_string_method import FSMSettings
 
 from .protein import Protein
 from .utils import api_client
@@ -285,16 +286,21 @@ def retrieve_workflow(uuid: str) -> Workflow:
         return Workflow(**response.json())
 
 
-def retrieve_calculation_molecules(uuid: str) -> list[dict[str, Any]]:
+def retrieve_calculation_molecules(
+    uuid: str, return_frequencies: bool = False
+) -> list[dict[str, Any]]:
     """
     Retrieves a list of molecules from a calculation.
 
     :param uuid: The UUID of the calculation to retrieve molecules from.
+    :param return_frequencies: Whether to return the frequencies of the molecules.
     :return: A list of dictionaries representing the molecules in the calculation.
     :raises HTTPError: If the API request fails.
     """
     with api_client() as client:
-        response = client.get(f"/calculation/{uuid}/molecules")
+        response = client.get(
+            f"/calculation/{uuid}/molecules", params={"return_frequencies": return_frequencies}
+        )
         response.raise_for_status()
         return response.json()
 
@@ -352,9 +358,10 @@ def list_workflows(
 def submit_basic_calculation_workflow(
     initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
     method: stjames.Method | str = "uma_m_omol",
+    basis_set: stjames.BasisSet | str | None = None,
     tasks: list[str] | None = None,
     mode: str = "auto",
-    engine: str = "omol25",
+    engine: str | None = None,
     name: str = "Basic Calculation Workflow",
     folder_uuid: str | None = None,
     max_credits: int | None = None,
@@ -364,7 +371,7 @@ def submit_basic_calculation_workflow(
 
     :param initial_molecule: The molecule to perform the calculation on.
     :param method: The method to use for the calculation.
-    See [list of available methods](https://github.com/rowansci/stjames-public/blob/master/stjames/method.py)
+    :param basis_set: The basis_set to use (if any).
     for options.
     :param tasks: A list of tasks to perform for the calculation.
     :param mode: The mode to run the calculation in. See [list of available modes](https://github.com/rowansci/stjames-public/blob/master/stjames/mode.py)
@@ -391,6 +398,7 @@ def submit_basic_calculation_workflow(
         initial_molecule=initial_molecule,
         settings=stjames.Settings(
             method=method,
+            basis_set=basis_set,
             tasks=tasks,
             mode=mode,
         ),
@@ -792,7 +800,7 @@ def submit_descriptors_workflow(
 def submit_scan_workflow(
     initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
     scan_settings: stjames.ScanSettings | dict[str, Any] | None = None,
-    calculation_engine: str = "omol25",
+    calculation_engine: str | None = None,
     calculation_method: stjames.Method | str = "uma_m_omol",
     wavefront_propagation: bool = True,
     name: str = "Scan Workflow",
@@ -835,7 +843,7 @@ def submit_scan_workflow(
         initial_molecule=initial_molecule,
         scan_settings=scan_settings,
         calc_settings=calc_settings,
-        calc_engine=calculation_engine,
+        calc_engine=calculation_engine or calculation_method.default_engine(),
         wavefront_propagation=wavefront_propagation,
     )
 
@@ -911,7 +919,6 @@ def submit_macropka_workflow(
 def submit_irc_workflow(
     initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol | None = None,
     method: stjames.Method | str = "uma_m_omol",
-    engine: str = "omol25",
     preopt: bool = True,
     step_size: float = 0.05,
     max_irc_steps: int = 30,
@@ -926,7 +933,6 @@ def submit_irc_workflow(
     :param method: The computational method to use for the IRC calculation.
     See [list of available methods](https://github.com/rowansci/stjames-public/blob/master/stjames/method.py)
     for options.
-    :param engine: The computational engine to use for the calculation. See [list of available engines](https://github.com/rowansci/stjames-public/blob/master/stjames/engine.py)
     :param preopt: Whether to perform a pre-optimization of the molecule.
     :param step_size: The step size to use for the IRC calculation.
     :param max_irc_steps: The maximum number of IRC steps to perform.
@@ -953,12 +959,12 @@ def submit_irc_workflow(
             corrections=[],
             mode="auto",
         ),
-        engine=engine,
         preopt=preopt,
         step_size=step_size,
         max_irc_steps=max_irc_steps,
         mode="manual",
     )
+
     data = {
         "name": name,
         "folder_uuid": folder_uuid,
@@ -1229,3 +1235,51 @@ def submit_strain_workflow(
         response = client.post("/workflow", json=data)
         response.raise_for_status()
         return Workflow(**response.json())
+
+
+def submit_double_ended_ts_search_workflow(
+    reactant: dict[str, Any] | StJamesMolecule,
+    product: dict[str, Any] | StJamesMolecule,
+    calculation_settings: stjames.Settings | dict[str, Any] | None = None,
+    search_settings: FSMSettings | dict[str, Any] | None = None,
+    optimize_inputs: bool = False,
+    optimize_ts: bool = True,
+    name: str = "Double-Ended TS Search Workflow",
+    folder_uuid: str | None = None,
+    max_credits: int | None = None,
+) -> Workflow:
+    """
+    Submits a double-ended transition state search workflow to the API.
+
+    :param reactant: reactant Molecule.
+    :param product: product Molecule.
+    :param calculation_settings: Settings to use for calculations.
+    :param search_settings: settings to use for the transition state search.
+    :param optimize_inputs: Whether to optimize the reactant and product before the search.
+    :param optimize_ts: Whether to optimize the found transition state.
+    :param name: name of the workflow.
+    :param folder_uuid: The UUID of the folder to place the workflow in.
+    :param max_credits: The maximum number of credits to use for the workflow.
+    :return: Workflow object representing the submitted workflow.
+    """
+    workflow = stjames.DoubleEndedTSSearchWorkflow(
+        reactant=reactant,
+        product=product,
+        calculation_settings=calculation_settings,
+        search_settings=search_settings,
+        optimize_inputs=optimize_inputs,
+        optimize_ts=optimize_ts,
+    )
+    data = {
+        "name": name,
+        "folder_uuid": folder_uuid,
+        "workflow_type": "double_ended_ts_search",
+        "workflow_data": workflow.model_dump(),
+        "initial_molecule": reactant if isinstance(reactant, dict) else reactant.model_dump(),
+        "max_credits": max_credits,
+    }
+
+    with api_client() as client:
+        response = client.post("/workflow", json=data)
+        response.raise_for_status()
+        return Workflow(**response.json())
